import React from "react";
import { CompactDisplay, CurrencyDisplay, CurrencySign, LocaleMatcher, Notation, NumberingSystem, SignDisplay, Style, UnitDisplay } from "./types";
export interface IntlNumberFormatOptions {
    compactDisplay?: CompactDisplay;
    currency?: string;
    currencyDisplay?: CurrencyDisplay;
    currencySign?: CurrencySign;
    localeMatcher?: LocaleMatcher;
    notation?: Notation;
    numberingSystem?: NumberingSystem;
    signDisplay?: SignDisplay;
    style?: Style;
    unit?: string;
    unitDisplay?: UnitDisplay;
    useGrouping?: boolean;
    minimumIntegerDigits?: number;
    minimumFractionDigits?: number;
    maximumFractionDigits?: number;
    minimumSignificantDigits?: number;
    maximumSignificantDigits?: number;
}
interface IntlNumberFormatProps {
    /**
     * The locale(s) used for the formating.
     *
     * Check {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat/NumberFormat|Intl.NumberFormat}.
     */
    locales?: string | string[];
    /**
     * The formating options.
     *
     * Check {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat/NumberFormat|Intl.NumberFormat} for the supported options.
     */
    options?: IntlNumberFormatOptions;
}
/**
 * Props of the AdvancedNumber component.
 *
 * They include the props for the formatting via {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat/NumberFormat|Intl.NumberFormat}
 */
export interface AdvancedNumberProps extends IntlNumberFormatProps {
    /**
     * The value to format. Ensure it's a number otherwise Int.NumberFormat will break.
     *
     * Check the 'options' property for the formatting configuration (currency, percentage, ...)
     *
     * @type number
     */
    value: number;
    /**
     * A boolean to enable (true) or disable (false) representing the decimal smaller than the integer.
     *
     * Default is false.
     *
     * @type boolean
     */
    smallDecimals?: boolean;
    /**
     * A boolean to enable (true) or disable (false) the privacy mode.
     *
     * Default is false.
     *
     * @type boolean
     */
    privacyMode?: boolean;
    /**
     * Color to use for the shadow of the privacy mode.
     *
     * Default is #7C7C7CD9.
     *
     * @type string
     */
    privacyShadowColor?: string;
    /**
     * Optionally, the value to check the difference from.
     *
     * Providing this previousValue implies the difference will be highlighted.
     * Leave it undefined if you don't want to.
     *
     * @type number
     */
    previousValue?: number;
    /**
     * Color to use for a positive difference between the value and the previous value.
     *
     * Ignored if previousValue is not provided.
     *
     * Default is #4CAF50.
     *
     * @type string
     */
    positiveColor?: string;
    /**
     * Color to use for a negative difference between the value and the previous value.
     *
     * Ignored if previousValue is not provided.
     *
     * Default is #F44336.
     *
     * @type string
     */
    negativeColor?: string;
    /**
     *  The number of decimal to display.
     * This property overrides both options.minimumFractionDigits and options.maximumFractionDigits.
     *
     * If undefined, the defaults from {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat/NumberFormat|Intl.NumberFormat} are used.
     *
     * * @type number
     */
    significantDecimalDigits?: number;
    /**
     * A boolean to enable (true) or disable (false) the representation of the muted decimals. the prop maxDecimalDigits must also be set.
     *
     * Muted decimals is disable if the prop options.notation is different than "standard"
     *
     * Default is false.
     *
     * @type boolean
     */
    showMutedDecimals?: boolean;
    /**
     * The total number of decimal digits displayed when muted decimals is enabled (ignored if disabled).
     *
     * The muted decimals correspond to the difference between maxDecimalDigits and significantDecimalDigits, assuming maxDecimalDigits is greater.
     *
     * @type number
     */
    maxDecimalDigits?: number;
}
/**
 * This component allows formatting and rendering a number using the {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat|Intl.NumberFormat API}. The formatting options of the API are provided as props of this component.
 *
 * In additiona, specific features are also provided such as:
 * - Optionaly have smaller decimals
 * - Highlighting a difference between the value and a previous value.
 * - A privacy mode, blurrying the value when enabled.
 * - Displaying muted decimals between a significant number and the total number of decimals
 *
 * If provided, the ref is forwarded to the root span element.
 */
export declare const AdvancedNumber: React.ForwardRefExoticComponent<AdvancedNumberProps & React.HTMLAttributes<HTMLSpanElement> & React.RefAttributes<HTMLSpanElement>>;
export {};
